@@ -16,16 +16,16 @@ from classy_imaginary.img_utils import pillow_fit_image_within, pillow_img_to_to
 from classy_imaginary.log_utils import ImageLoggingContext, log_conditioning, log_img, log_latent
 from classy_imaginary.model_manager import get_diffusion_model
 from classy_imaginary.modules.midas.utils import AddMiDaS
-from classy_imaginary.safety import create_safety_score
+from classy_imaginary.safety import create_safety_score, EnhancedStableDiffusionSafetyChecker
 from classy_imaginary.samplers import SAMPLER_LOOKUP
 from classy_imaginary.samplers.base import NoiseSchedule, noise_an_image
 from classy_imaginary.utils import get_device, platform_appropriate_autocast, fix_torch_nn_layer_norm, fix_torch_group_norm, randn_seeded
 import logging
-from transformers import logging
+from transformers import logging as transformers_logging, AutoFeatureExtractor
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.INFO)
-logging.set_verbosity_error()
+transformers_logging.set_verbosity_error()
 # logging.disable_default_handler()
 
 
@@ -49,6 +49,11 @@ class Imagine:
             for_inpainting=for_inpainting,
         )
         self.midas_model = AddMiDaS()
+        safety_model_id = "CompVis/stable-diffusion-safety-checker"
+        self.safety_feature_extractor = AutoFeatureExtractor.from_pretrained(safety_model_id)
+        self.safety_checker = EnhancedStableDiffusionSafetyChecker.from_pretrained(
+            safety_model_id
+        )
 
     def imagine(self,
                 prompt: ImaginePrompt,
@@ -323,8 +328,10 @@ class Imagine:
 
                     with lc.timing("safety-filter"):
                         safety_score = create_safety_score(
+                            self.safety_checker,
+                            self.safety_feature_extractor,
                             img,
-                            safety_mode=IMAGINAIRY_SAFETY_MODE,
+                            safety_mode=IMAGINAIRY_SAFETY_MODE
                         )
 
                     if not safety_score.is_filtered:
